@@ -16,10 +16,6 @@ Htmlgen::FileUtil
 =head1 DESCRIPTION
 
 
-=head1 NOTE
-
-This is alpha software! Read the package README.
-
 =cut
 
 
