@@ -17,19 +17,13 @@ Chj::IO::Pipe
 
 Inherits from Chj::IO::File.
 
-=head1 NOTE
-
-This is alpha software! Read the status section in the package README
-or on the L<website|http://functional-perl.org/>.
-
 =cut
 
+
 package Chj::IO::Pipe;
-@ISA = "Chj::IO::File";
+@ISA= "Chj::IO::File";
 require Chj::IO::File;
-use strict;
-use warnings;
-use warnings FATAL => 'uninitialized';
+use strict; use warnings; use warnings FATAL => 'uninitialized';
 
 sub quotedname {
     "pipe"
