@@ -18,11 +18,6 @@ Chj::Package::OfPath
 (Taken from chj-bin's perl_path2namespace.)
 
 
-=head1 NOTE
-
-This is alpha software! Read the status section in the package README
-or on the L<website|http://functional-perl.org/>.
-
 =cut
 
 
