@@ -14,7 +14,7 @@ Chj::TerseDumper
 =head1 SYNOPSIS
 
     use Chj::TerseDumper;
-    my $foo = +{ foo => 1, bar => 10, baz => -1 };
+    my $foo= +{ foo=> 1, bar=> 10, baz=>-1 };
     is terseDumper($foo), "XXX";
     is TerseDumper($foo), "XXX";
 
@@ -22,39 +22,34 @@ Chj::TerseDumper
 
 Runs Data::Dumper's Dumper with $Data::Dumper::Terse set to 1.
 
-=head1 NOTE
-
-This is alpha software! Read the status section in the package README
-or on the L<website|http://functional-perl.org/>.
-
 =cut
 
-package Chj::TerseDumper;
-use strict;
-use warnings;
-use warnings FATAL => 'uninitialized';
-use Exporter "import";
 
-our @EXPORT      = qw(TerseDumper terseDumper);
-our @EXPORT_OK   = qw(UnsortedTerseDumper);
-our %EXPORT_TAGS = (all => [@EXPORT, @EXPORT_OK]);
+package Chj::TerseDumper;
+@ISA="Exporter"; require Exporter;
+@EXPORT=qw(TerseDumper terseDumper);
+@EXPORT_OK=qw(UnsortedTerseDumper);
+%EXPORT_TAGS=(all=>[@EXPORT,@EXPORT_OK]);
+
+use strict; use warnings; use warnings FATAL => 'uninitialized';
 
 use Data::Dumper;
 
 sub UnsortedTerseDumper {
-    local $Data::Dumper::Terse = 1;
+    local $Data::Dumper::Terse= 1;
     Dumper(@_)
 }
 
 sub TerseDumper {
-    local $Data::Dumper::Sortkeys = 1;
-    UnsortedTerseDumper(@_)
+    local $Data::Dumper::Sortkeys= 1;
+    UnsortedTerseDumper (@_)
 }
 
 sub terseDumper {
-    my $str = TerseDumper(@_);
+    my $str= TerseDumper (@_);
     chomp $str;
     $str
 }
 
+
 1
