@@ -16,26 +16,23 @@ Chj::Unix::Signal
 =head1 DESCRIPTION
 
 
-=head1 NOTE
-
-This is alpha software! Read the status section in the package README
-or on the L<website|http://functional-perl.org/>.
-
 =cut
 
+
 package Chj::Unix::Signal;
 
-use strict;
-use warnings;
-use warnings FATAL => 'uninitialized';
+use strict; use warnings; use warnings FATAL => 'uninitialized';
+
+use Class::Array -fields=>
+  -publica=>
+  'number',
+  ;
 
-use Chj::Class::Array -fields => -publica => 'number',
-    ;
 
 sub new {
-    my $class = shift;
-    my $s     = $class->SUPER::new;
-    ($$s[Number]) = @_;
+    my $class=shift;
+    my $s= $class->SUPER::new;
+    ($$s[Number])=@_;
     $s
 }
 
@@ -43,19 +40,18 @@ sub new {
 # and /bin/kill doesn't know all of them, bush eh bash is much better.
 # ah, man perlipc "Signals":
 
-our $inited = 0;
+our $inited=0;
 our $signo;
 our $signame;
-
 sub MaybeInit {
     $inited ||= do {
         require Config;
-        my $cfg = $Config::Config{sig_name};
+        my $cfg= $Config::Config{sig_name};
         defined $cfg or die "No sigs?";
-        my $i = 0;
+        my $i=0;
         foreach my $name (split(' ', $cfg)) {
-            $$signo{$name} = $i;
-            $$signame[$i] = $name;
+            $$signo{$name}= $i;
+            $$signame[$i]= $name;
             $i++
         }
         1
@@ -63,10 +59,10 @@ sub MaybeInit {
 }
 
 sub as_string {
-    my $s = shift;
+    my $s=shift;
     MaybeInit;
-    my $maybe_str = $$signame[$$s[Number]];
+    my $maybe_str= $$signame[$$s[Number]];
     defined $maybe_str ? $maybe_str : "<unknown signal (number $$s[Number])>"
 }
 
-end Chj::Class::Array;
+end Class::Array;
