@@ -13,13 +13,13 @@ Chj::Util::AskYN
 
 =head1 SYNOPSIS
 
-    use Chj::Util::AskYN;
+ use Chj::Util::AskYN;
 
-    LP: {
-        if (maybe_askyn "Do you want to retry?") {
-            redo LP;
-        }
-    }
+ LP: {
+     if (maybe_askyn "Do you want to retry?") {
+         redo LP;
+     }
+ }
 
 =head1 DESCRIPTION
 
@@ -32,42 +32,35 @@ returned.
 
 Delete this and use something else?
 
-=head1 NOTE
-
-This is alpha software! Read the status section in the package README
-or on the L<website|http://functional-perl.org/>.
-
 =cut
 
-package Chj::Util::AskYN;
-use Exporter "import";
-our @EXPORT = qw(maybe_askyn);
 
-use strict;
-use warnings;
-use warnings FATAL => 'uninitialized';
+package Chj::Util::AskYN;
+@ISA="Exporter"; require Exporter;
+@EXPORT= qw(maybe_askyn);
+
+use strict; use warnings; use warnings FATAL => 'uninitialized';
 
 sub maybe_askyn {
-    my ($maybe_prompt) = @_;
-    local $| = 1;
-ASK: {
+    my ($maybe_prompt)=@_;
+    local $|=1;
+  ASK:{
         if (defined $maybe_prompt) {
             print $maybe_prompt;
         }
         print " ";
-        my $ans = <STDIN>;
+        my $ans=<STDIN>;
         if (defined $ans) {
-            if ($ans =~ /^n(?:o|ein|ada|on)?$/i) {
+            if ($ans=~ /^n(?:o|ein|ada|on)?$/i) {
                 ''
-            } elsif ($ans =~ /^(?:ja|yes|j|y|oui)$/i) {
+            } elsif ($ans=~ /^(?:ja|yes|j|y|oui)$/i){
                 1
             } else {
-                print "Please answer with yes or no or their initials, "
-                    . "or the same in french or german.\n";
+                print "Please answer with yes or no or their initials, ".
+                  "or the same in french or german.\n";
                 redo ASK;
             }
         } else {
-
             # EOF, i.e. ctl-d
             print "\n";
             undef
