@@ -30,35 +30,41 @@ those within the given packages.
 
 L<Chj::TEST>
 
-=head1 NOTE
-
-This is alpha software! Read the status section in the package README
-or on the L<website|http://functional-perl.org/>.
-
 =cut
 
-package Chj::noTEST;
-use strict;
-use warnings;
-use warnings FATAL => 'uninitialized';
-use Exporter "import";
 
-our @EXPORT      = qw(TEST TEST_STDOUT TEST_EXCEPTION GIVES perhaps_run_tests);
-our @EXPORT_OK   = qw();
-our %EXPORT_TAGS = (all => [@EXPORT, @EXPORT_OK]);
+package Chj::noTEST;
+@ISA="Exporter"; require Exporter;
+@EXPORT=qw(TEST TEST_STDOUT TEST_EXCEPTION GIVES perhaps_run_tests);
+@EXPORT_OK=qw();
+%EXPORT_TAGS=(all=>[@EXPORT,@EXPORT_OK]);
+
+use strict; use warnings; use warnings FATAL => 'uninitialized';
 
 use Chj::TEST ();
 
-*import = *Chj::TEST::import;
+*import= *Chj::TEST::import;
 
-sub TEST (&$) { () }
 
-sub TEST_STDOUT (&$) { () }
+sub TEST (&$) {
+    ()
+}
 
-sub TEST_EXCEPTION (&$) { () }
+sub TEST_STDOUT (&$) {
+    ()
+}
 
-sub GIVES (&) { () }
+sub TEST_EXCEPTION (&$) {
+    ()
+}
+
+sub GIVES (&) {
+    ()
+}
+
+sub perhaps_run_tests {
+    ()
+}
 
-sub perhaps_run_tests { () }
 
 1
