@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2003-2020 Christian Jaeger, copying@christianjaeger.ch
+# Copyright (c) 2003-2014 Christian Jaeger, copying@christianjaeger.ch
 #
 # This is free software, offered under either the same terms as perl 5
 # or the terms of the Artistic License version 2 or the terms of the
@@ -13,13 +13,13 @@ Chj::xopendir
 
 =head1 SYNOPSIS
 
-    use Chj::xopendir;
-    {
-        my $dir = xopendir "/foo";
-        while (defined(my $item = $dir->read)) {
-            print $item;
-        }
-    } # $dir is closed automatically (issuing a warning on error)
+ use Chj::xopendir;
+ {
+     my $dir= xopendir "/foo";
+     while (defined(my $item=$dir->read)) {
+         print $item;
+     }
+ } # $dir is closed automatically (issuing a warning on error)
 
 =head1 DESCRIPTION
 
@@ -91,40 +91,28 @@ is issued upon errors in that case.)
 
 L<Chj::xopen>
 
-=head1 NOTE
-
-This is alpha software! Read the status section in the package README
-or on the L<website|http://functional-perl.org/>.
-
 =cut
 
 #'
 
 package Chj::xopendir;
-use strict;
-use warnings;
-use warnings FATAL => 'uninitialized';
+@ISA='Exporter'; require Exporter;
+@EXPORT= qw(xopendir perhaps_opendir perhaps_xopendir);
+
+use strict; use warnings; use warnings FATAL => 'uninitialized';
 use Chj::IO::Dir;
-use Exporter 'import';
 
-our @EXPORT = qw(xopendir perhaps_opendir perhaps_xopendir);
-
-use FP::Carp;
-
-sub xopendir {
-    @_ == 1 or fp_croak_nargs 1;
+sub xopendir($) {
     unshift @_, 'Chj::IO::Dir';
     goto &Chj::IO::Dir::xopendir;
 }
 
-sub perhaps_opendir {
-    @_ == 1 or fp_croak_nargs 1;
+sub perhaps_opendir($) {
     unshift @_, 'Chj::IO::Dir';
     goto &Chj::IO::Dir::perhaps_opendir;
 }
 
-sub perhaps_xopendir {
-    @_ == 1 or fp_croak_nargs 1;
+sub perhaps_xopendir($) {
     unshift @_, 'Chj::IO::Dir';
     goto &Chj::IO::Dir::perhaps_xopendir;
 }
