@@ -13,10 +13,10 @@ Chj::xpipe
 
 =head1 SYNOPSIS
 
-    use Chj::xpipe;
-    my ($read,$write) = xpipe; # or xpipe READ,WRITE ? hmmm. not yet.
-    $read->xclose;
-    $write->xprint("Hello");
+ use Chj::xpipe;
+ my ($read,$write)=xpipe; # or xpipe READ,WRITE ? hmmm. not yet.
+ $read->xclose;
+ $write->xprint("Hello");
 
 =head1 DESCRIPTION
 
@@ -31,20 +31,14 @@ is thrown.
 
 L<Chj::IO::Pipe>, L<Chj::IO::File>
 
-=head1 NOTE
-
-This is alpha software! Read the status section in the package README
-or on the L<website|http://functional-perl.org/>.
-
 =cut
 
+
 package Chj::xpipe;
-@ISA = 'Exporter';
+@ISA='Exporter';
 require Exporter;
-our @EXPORT = qw(xpipe);
-use strict;
-use warnings;
-use warnings FATAL => 'uninitialized';
+@EXPORT= qw(xpipe);
+use strict; use warnings; use warnings FATAL => 'uninitialized';
 
 use Chj::IO::Pipe;
 use Carp;
@@ -53,10 +47,10 @@ sub xpipe {
     if (@_) {
         confess "form with arguments not yet supported";
     } else {
-        my $r = new Chj::IO::Pipe;
-        my $w = new Chj::IO::Pipe;
-        pipe $r, $w or croak "xpipe: $!";
-        ($r, $w)
+        my $r=new Chj::IO::Pipe;
+        my $w=new Chj::IO::Pipe;
+        pipe $r,$w or croak "xpipe: $!";
+        ($r,$w)
     }
 }
 
