@@ -31,33 +31,12 @@ purpose is:
 
 Point (2) is implemented by `FP::Struct`: when defining a class via
 `FP::Struct`, each given parent class is checked for the
-implementation of a method `FP_Interface__method_names` via
+implementation of a method `fp_interface_method_names` via
 `can()`. This method, if present, is supposed to ignore arguments and
 return a list of the names of the set of methods that is required to
 implement the interface.  This method is called once at load time of
 each module that defines such a class.
 
-=head1 FUTURE / TODO
-
-Not only declare and check the method names, but also the arity (how
-many arguments it takes), argument names, and, once FP::Types is done,
-optionally types.
-
-At that point, offer more methods for introspection (IDE support).
-
-Extend to generic functions that support the same "methods" on
-unblessed references or non-reference values.
-
-Perhaps (given some reason) rename FP::Abstract::* to FP::Protocol::*.
-
-=head1 SEE ALSO
-
-L<FP::Interfaces>
-
-=head1 NOTE
-
-This is alpha software! Read the status section in the package README
-or on the L<website|http://functional-perl.org/>.
 
 =cut
 
@@ -66,11 +45,11 @@ package FP::Abstract::Interface;
 
 use strict; use warnings; use warnings FATAL => 'uninitialized';
 
-sub FP_Interface__method_names {
+sub fp_interface_method_names {
     my $class= shift;
     # If we're extending another interface (not the case here though),
     # we need to merge its interface definition with ours:
-    ((), $class->SUPER::FP_Interface__method_names)
+    ((), $class->SUPER::fp_interface_method_names)
 }
 
 1
