@@ -25,11 +25,6 @@ I'm pretty sure this is still re-inventing some wheel...
 
 L<FP::Repl::Stack>, L<PadWalker>
 
-=head1 NOTE
-
-This is alpha software! Read the status section in the package README
-or on the L<website|http://functional-perl.org/>.
-
 =cut
 
 
