@@ -13,8 +13,8 @@ FP::Repl::Trap
 
 =head1 SYNOPSIS
 
-    use FP::Repl::Trap;
-    die "fun"; # opens a repl from FP::Repl
+ use FP::Repl::Trap;
+ die "fun"; # opens a repl from FP::Repl
 
 =head1 DESCRIPTION
 
@@ -28,11 +28,6 @@ NOTE: the name is not set in stone yet, also, perhaps it should be
 
 L<FP::Repl::WithRepl>, L<FP::Repl::AutoTrap>
 
-=head1 NOTE
-
-This is alpha software! Read the status section in the package README
-or on the L<website|http://functional-perl.org/>.
-
 =cut
 
 
@@ -42,10 +37,6 @@ use strict; use warnings; use warnings FATAL => 'uninitialized';
 
 use FP::Repl::WithRepl;
 
-if (($ENV{RUN_TESTS}//'') eq '1') {
-    warn "not activating since running in test mode";
-} else {
-    push_withrepl (0);
-}
+push_withrepl (0);
 
 1
