@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2004-2022 Christian Jaeger, copying@christianjaeger.ch
+# Copyright (c) 2004-2014 Christian Jaeger, copying@christianjaeger.ch
 #
 # This is free software, offered under either the same terms as perl 5
 # or the terms of the Artistic License version 2 or the terms of the
@@ -7,8 +7,6 @@
 # bundled with this file.
 #
 
-# Depends: ()
-
 =head1 NAME
 
 FP::Repl::corefuncs
@@ -19,24 +17,18 @@ FP::Repl::corefuncs
 
 Returns a list of all perl CORE functions
 
-=head1 NOTE
-
-This is alpha software! Read the status section in the package README
-or on the L<website|http://functional-perl.org/>.
-
 =cut
 
-package FP::Repl::corefuncs;
-use Exporter "import";
-our @EXPORT = qw(corefuncs);
 
-use strict;
-use warnings;
-use warnings FATAL => 'uninitialized';
+package FP::Repl::corefuncs;
+@ISA="Exporter"; require Exporter;
+@EXPORT=qw(corefuncs);
+
+use strict; use warnings; use warnings FATAL => 'uninitialized';
 
 {
     # for some reason I can't seem to find out how to get at that otherwise.
-    my $txt = <<'END';
+    my $txt=<<'END';
     
        Functions for SCALARs or strings
            "chomp", "chop", "chr", "crypt", "hex", "index", "lc", "lcfirst", "length",
@@ -96,7 +88,7 @@ use warnings FATAL => 'uninitialized';
            "bless", "dbmclose", "dbmopen", "package", "ref", "tie", "tied", "untie", "use"
 
        Low-level socket functions
-           "accept", "bind", "connect", "getpeername", "getsockname", "getsockopt", "lis­
+           "accept", "bind", "connect", "getpeername", "getsockname", "getsockopt", "lis
            ten", "recv", "send", "setsockopt", "shutdown", "socket", "socketpair"
 
        System V interprocess communication functions
@@ -105,13 +97,13 @@ use warnings FATAL => 'uninitialized';
 
        Fetching user and group info
            "endgrent", "endhostent", "endnetent", "endpwent", "getgrent", "getgrgid",
-           "getgrnam", "getlogin", "getpwent", "getpwnam", "getpwuid", "setgrent", "setp­
+           "getgrnam", "getlogin", "getpwent", "getpwnam", "getpwuid", "setgrent", "setp
            went"
 
        Fetching network info
            "endprotoent", "endservent", "gethostbyaddr", "gethostbyname", "gethostent",
-           "getnetbyaddr", "getnetbyname", "getnetent", "getprotobyname", "getprotobynum­
-           ber", "getprotoent", "getservbyname", "getservbyport", "getservent", "sethos­
+           "getnetbyaddr", "getnetbyname", "getnetent", "getprotobyname", "getprotobynum
+           ber", "getprotoent", "getservbyname", "getservbyport", "getservent", "sethos
            tent", "setnetent", "setprotoent", "setservent"
 
        Time-related functions
@@ -123,17 +115,19 @@ use warnings FATAL => 'uninitialized';
            "readpipe", "ref", "sub*", "sysopen", "tie", "tied", "uc", "ucfirst", "untie",
            "use"
 END
-
-    $txt =~ s/(\w)[-­]\s*(\w)/$1$2/sg
-        ;    # careful: the -­ are two different chars.
-             #print $txt;
-    my @corefuncs = grep { length($_) >= 3 } $txt =~ /"(\w+)"/g;
+  ;
+    $txt=~ s/(\w)[-]\s*(\w)/$1$2/sg;# careful: the - are two different chars.
+    #print $txt;
+    my @corefuncs= grep {
+        length($_)>=3
+    }
+      $txt=~ /"(\w+)"/g;
     no warnings 'redefine';
-    *corefuncs = sub {
+    *corefuncs= sub {
         @corefuncs
     };
 }
 
-*FP::Repl::corefuncs = \&corefuncs;
+*FP::Repl::corefuncs= \&corefuncs;
 
 1
