@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2015-2020 Christian Jaeger, copying@christianjaeger.ch
+# Copyright (c) 2015-2019 Christian Jaeger, copying@christianjaeger.ch
 #
 # This is free software, offered under either the same terms as perl 5
 # or the terms of the Artistic License version 2 or the terms of the
@@ -16,13 +16,13 @@ FP::Trampoline -- tail call optimization without reliance on goto
     use FP::Trampoline; # exports `T` and `trampoline`
 
     sub iterative_fact {
-        my ($n,$tot) = @_;
+        my ($n,$tot)= @_;
         $n > 1 ? T{ iterative_fact ($n-1, $tot*$n) } : $tot
         # or
-        # $n > 1 ? TC \&iterative_fact, $n-1, $tot*$n : $tot
+        # $n > 1 ? TC *iterative_fact, $n-1, $tot*$n : $tot
     }
     sub fact {
-        my ($n) = @_;
+        my ($n)=@_;
         trampoline iterative_fact ($n, 1)
     }
     is fact(5), 120;
@@ -43,8 +43,6 @@ language. Its drawbacks are more overhead and the requirement to put a
 
 =head1 FUNCTIONS
 
-=over 4
-
 =item T { ... }
 
 Returns a closure blessed into the `FP::Trampoline::Continuation`
@@ -64,26 +62,16 @@ The trampoline that bounces back as long as it receives a trampolining
 continuation: if so, the continuation is run, and the result passed to
 the `trampoline` again, otherwise it is returned directly.
 
-=back
-
-=head1 NOTE
-
-This is alpha software! Read the status section in the package README
-or on the L<website|http://functional-perl.org/>.
-
 =cut
 
+
 package FP::Trampoline;
-use strict;
-use warnings;
-use warnings FATAL => 'uninitialized';
-use Exporter "import";
+@ISA="Exporter"; require Exporter;
+@EXPORT=qw(T TC trampoline);
+@EXPORT_OK=qw();
+%EXPORT_TAGS=(all=>[@EXPORT,@EXPORT_OK]);
 
-our @EXPORT      = qw(T TC trampoline);
-our @EXPORT_OK   = qw();
-our %EXPORT_TAGS = (all => [@EXPORT, @EXPORT_OK]);
-
-use FP::Carp;
+use strict; use warnings; use warnings FATAL => 'uninitialized';
 
 sub T (&) {
     bless $_[0], "FP::Trampoline::Continuation"
@@ -93,21 +81,18 @@ sub TC {
     bless [@_], "FP::Trampoline::Call"
 }
 
-sub trampoline {
-    @_ == 1 or fp_croak_arity 1;
-    my ($v) = @_;
-    @_ = ();    # so that calling a continuation does not need () (possible
-                # speedup)
+sub trampoline ($) {
+    my ($v)=@_;
+    @_=(); # so that calling a continuation does not need () (possible
+           # speedup)
     while (1) {
-        if (my $r = ref $v) {
-            $v = (
-                  $r eq "FP::Trampoline::Continuation"
-                ? &$v
-                : $r eq "FP::Trampoline::Call" ? do {
-                    $$v[0]->(@$v[1 .. $#$v])
-                    }
-                : return $v
-            );
+        if (my $r= ref $v) {
+            $v=
+              ($r eq "FP::Trampoline::Continuation" ? &$v
+               : $r eq "FP::Trampoline::Call" ? do {
+                   $$v[0]->(@$v[1..$#$v])
+               }
+               : return $v);
         } else {
             return $v
         }
