@@ -13,24 +13,19 @@ PXML::Tags
 
 =head1 SYNOPSIS
 
-    use PXML::Tags qw(records
-        protocol-version
-        record);
-    my $xml= RECORDS(PROTOCOL_VERSION("1.0"),
-                     RECORD("Hi"), RECORD("there!"));
-    is ref($xml), "PXML::Element";
-    is $xml->string, '<records><protocol-version>1.0</protocol-version><record>Hi</record><record>there!</record></records>';
+ use PXML::Tags qw(records
+     protocol-version
+     record);
+ my $xml= RECORDS(PROTOCOL_VERSION("1.0"),
+                  RECORD("Hi"), RECORD("there!"));
+ is ref($xml), "PXML::Element";
+ is $xml->string, '<records><protocol-version>1.0</protocol-version><record>Hi</record><record>there!</record></records>';
 
 =head1 DESCRIPTION
 
 Creates tag wrappers that return PXML elements. The names of the
 wrappers are all uppercase, and "-" is replaced with "_".
 
-=head1 NOTE
-
-This is alpha software! Read the status section in the package README
-or on the L<website|http://functional-perl.org/>.
-
 =cut
 
 
