@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2013-2019 Christian Jaeger, copying@christianjaeger.ch
+# Copyright (c) 2013-2015 Christian Jaeger, copying@christianjaeger.ch
 #
 # This is free software, offered under either the same terms as perl 5
 # or the terms of the Artistic License version 2 or the terms of the
@@ -16,11 +16,6 @@ PXML::XHTML
 =head1 DESCRIPTION
 
 
-=head1 NOTE
-
-This is alpha software! Read the status section in the package README
-or on the L<website|http://functional-perl.org/>.
-
 =cut
 
 
@@ -34,7 +29,7 @@ use PXML::Element;
 our $nbsp= "\xa0";
 
 our $tags=
-    [
+     [
           'a',
           'abbr',
           'acronym',
@@ -105,7 +100,6 @@ our $tags=
           'script',
           'select',
           'small',
-          'source', # not XHTML?, hack
           'span',
           'strike',
           'strong',
@@ -124,8 +118,7 @@ our $tags=
           'tt',
           'u',
           'ul',
-          'var',
-          'video', # not XHTML?, hack
+          'var'
      ];
 
 our $funcs=
@@ -136,7 +129,7 @@ our $funcs=
         uc $tag,
         sub {
             my $atts= ref($_[0]) eq "HASH" ? shift : undef;
-            PXML::_::XHTML->new($tag, $atts, [@_]);
+            PXML::PXHTML->new($tag, $atts, [@_]);
         }
        ]
    } @$tags
@@ -151,8 +144,8 @@ for (@$funcs) {
 our @EXPORT_OK= ('$nbsp', map { $$_[0] } @$funcs);
 our %EXPORT_TAGS=(all=>\@EXPORT_OK);
 
-
-package PXML::_::XHTML {
+{
+    package PXML::PXHTML;
     our @ISA= "PXML::Element";
 
     # serialize to HTML5 compatible representation:
@@ -179,7 +172,7 @@ package PXML::_::XHTML {
         my $b= $s->body;
         (uc($s->name)."(".
          join(", ",
-              (defined($a) and keys %$a) ? &$show($a) : (),
+              defined $a ? &$show($a) : (),
               ref($b) eq "ARRAY" ? join(", ",map { &$show($_) } @$b)
               : &$show($b)).
          ")")
